System Requirements
===================

In this section, from the objective and context, we examined
user categories and their behavior.  After that, we analyzed the expected system
to see which features therewill be.  From there, we derived a list of
use cases for the system.  Finally, we add some supplementary specifications
for describing nonfunctional requirements.

.. toctree::
   :maxdepth: 2

   users
   break-down
   use-case/index
   suppl-spec
